/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2012-2022 Matthias Klumpp <matthias@tenstral.net>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the license, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __APPSTREAM_COMPOSE_H
#define __APPSTREAM_COMPOSE_H

#ifndef I_KNOW_THE_APPSTREAM_COMPOSE_API_IS_SUBJECT_TO_CHANGE
#error You have to define I_KNOW_THE_APPSTREAM_COMPOSE_API_IS_SUBJECT_TO_CHANGE
#endif

#define __APPSTREAM_COMPOSE_H_INSIDE__

#include <appstream.h>

#include <asc-globals.h>
#include <asc-compose.h>
#include <asc-icon-policy.h>
#include <asc-utils.h>
#include <asc-hint.h>
#include <asc-unit.h>
#include <asc-directory-unit.h>
#include <asc-result.h>
#include <asc-enums-types.h>

#include <asc-image.h>
#include <asc-canvas.h>

#undef __APPSTREAM_COMPOSE_H_INSIDE__

#endif /* __APPSTREAM_COMPOSE_H */
